from enum import Enum

from rooms_shared_services.src.storage.models import BaseDynamodbModel


class CurrencyCode(str, Enum):
    ILS = "ILS"


class GeoRelatedValues(BaseDynamodbModel):
    IL: str | float | int | None = None



from uuid import UUID

from rooms_shared_services.src.models.relations import GeoRelatedValues
from rooms_shared_services.src.storage.models import UNSET, BaseDynamodbModel


class ProductGroup(BaseDynamodbModel):
    id: UUID | UNSET = "UNSET"
    name: str | UNSET = "UNSET"
    brands: list[str] | UNSET = "UNSET"
    base_margins: GeoRelatedValues | UNSET = "UNSET"
